==> suir-component-mapper-3.2.1.tgz: package/esm/field-array/field-array.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useReducer } from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArray from "@data-driven-forms/react-form-renderer/field-array";
import Button from "semantic-ui-react/dist/es/elements/Button/Button.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import ButtonGroup from "semantic-ui-react/dist/es/elements/Button/ButtonGroup.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import { createUseStyles } from 'react-jss';
import clsx from 'clsx';
import FormField from '../form-field/form-field';
var useStyles = createUseStyles({
  buttonGroup: {
    display: 'flex',
    justifyContent: 'flex-end'
  },
  arrayItem: {
    marginBottom: '1em'
  },
  arrayItems: {
    marginTop: '1em'
  },
  error: {
    color: '#9f3a38 !important'
  },
  noItems: {
    paddingBottom: '1em'
  },
  noMargin: {
    margin: '0 !important'
  },
  arrayHeader: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center'
  }
});

var ArrayItem = function ArrayItem(_ref) {
  var fields = _ref.fields,
      fieldIndex = _ref.fieldIndex,
      name = _ref.name,
      remove = _ref.remove,
      length = _ref.length,
      minItems = _ref.minItems,
      removeLabel = _ref.removeLabel,
      RemoveButtonProps = _ref.RemoveButtonProps,
      _ref$ArrayItemGridPro = _ref.ArrayItemGridProps,
      arrayItemClassName = _ref$ArrayItemGridPro.className,
      ArrayItemGridProps = _objectWithoutProperties(_ref$ArrayItemGridPro, ["className"]),
      ArrayItemFieldsGridProps = _ref.ArrayItemFieldsGridProps;

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var classes = useStyles();
  var editedFields = fields.map(function (field, index) {
    var computedName = field.name ? "".concat(name, ".").concat(field.name) : name;
    return _objectSpread(_objectSpread({}, field), {}, {
      name: computedName,
      key: "".concat(computedName, "-").concat(index)
    });
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    className: clsx(classes.arrayItem, arrayItemClassName)
  }, ArrayItemGridProps), /*#__PURE__*/React.createElement("div", ArrayItemFieldsGridProps, renderForm([editedFields])), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Button, _extends({
    icon: "remove",
    content: removeLabel,
    basic: true,
    color: "red"
  }, RemoveButtonProps, {
    type: "button",
    onClick: function onClick() {
      return remove(fieldIndex);
    },
    disabled: length <= minItems
  }))));
};

ArrayItem.propTypes = {
  name: PropTypes.string,
  fieldIndex: PropTypes.number.isRequired,
  fields: PropTypes.arrayOf(PropTypes.object),
  remove: PropTypes.func.isRequired,
  length: PropTypes.number,
  minItems: PropTypes.number,
  removeLabel: PropTypes.node.isRequired,
  RemoveButtonProps: PropTypes.object,
  ArrayItemGridProps: PropTypes.object,
  ArrayItemFieldsGridProps: PropTypes.object
};
ArrayItem.defaultProps = {
  RemoveButtonProps: {},
  ArrayItemGridProps: {},
  ArrayItemFieldsGridProps: {}
};
var defaultButtonLabels = {
  add: 'ADD',
  remove: 'REMOVE'
};
var initialState = {
  index: 0,
  history: []
};
export var reducer = function reducer(state, _ref2) {
  var type = _ref2.type,
      action = _ref2.action;

  switch (type) {
    case 'redo':
      return _objectSpread(_objectSpread({}, state), {}, {
        index: state.index + 1
      });

    case 'action':
      return {
        index: state.index + 1,
        history: [].concat(_toConsumableArray(state.history.slice(0, state.index)), [action])
      };

    case 'undo':
      return _objectSpread(_objectSpread({}, state), {}, {
        index: state.index - 1
      });

    case 'resetHistory':
      return _objectSpread(_objectSpread({}, state), {}, {
        history: state.history.slice(0, state.index)
      });

    default:
      return state;
  }
};

var DynamicArray = function DynamicArray(_ref3) {
  var props = _extends({}, _ref3);

  var _useFieldApi = useFieldApi(props),
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      formFields = _useFieldApi.fields,
      defaultItem = _useFieldApi.defaultItem,
      meta = _useFieldApi.meta,
      minItems = _useFieldApi.minItems,
      maxItems = _useFieldApi.maxItems,
      noItemsMessage = _useFieldApi.noItemsMessage,
      buttonLabels = _useFieldApi.buttonLabels,
      FieldArrayGridProps = _useFieldApi.FieldArrayGridProps,
      _useFieldApi$FieldArr = _useFieldApi.FieldArrayHeaderProps,
      arrayHeaderClassName = _useFieldApi$FieldArr.className,
      FieldArrayHeaderProps = _objectWithoutProperties(_useFieldApi$FieldArr, ["className"]),
      _useFieldApi$FieldArr2 = _useFieldApi.FieldArrayButtonGridProps,
      arrayButtonGridClassName = _useFieldApi$FieldArr2.className,
      FieldArrayButtonGridProps = _objectWithoutProperties(_useFieldApi$FieldArr2, ["className"]),
      ButtonGroupProps = _useFieldApi.ButtonGroupProps,
      UndoButtonProps = _useFieldApi.UndoButtonProps,
      RedoButtonProps = _useFieldApi.RedoButtonProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      _useFieldApi$Descript = _useFieldApi.DescriptionProps,
      descriptionClassName = _useFieldApi$Descript.className,
      DescriptionProps = _objectWithoutProperties(_useFieldApi$Descript, ["className"]),
      _useFieldApi$ArrayIte = _useFieldApi.ArrayItemsGridProps,
      arrayItemsClassName = _useFieldApi$ArrayIte.className,
      ArrayItemsGridProps = _objectWithoutProperties(_useFieldApi$ArrayIte, ["className"]),
      _useFieldApi$NoItemsP = _useFieldApi.NoItemsProps,
      noItemsClassname = _useFieldApi$NoItemsP.className,
      NoItemsProps = _objectWithoutProperties(_useFieldApi$NoItemsP, ["className"]),
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      ArrayItemGridProps = _useFieldApi.ArrayItemGridProps,
      ArrayItemFieldsGridProps = _useFieldApi.ArrayItemFieldsGridProps,
      rest = _objectWithoutProperties(_useFieldApi, ["arrayValidator", "label", "description", "fields", "defaultItem", "meta", "minItems", "maxItems", "noItemsMessage", "buttonLabels", "FieldArrayGridProps", "FieldArrayHeaderProps", "FieldArrayButtonGridProps", "ButtonGroupProps", "UndoButtonProps", "RedoButtonProps", "AddButtonProps", "DescriptionProps", "ArrayItemsGridProps", "NoItemsProps", "RemoveButtonProps", "ArrayItemGridProps", "ArrayItemFieldsGridProps"]);

  var _useReducer = useReducer(reducer, initialState),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  var classes = useStyles();

  var combinedButtonLabels = _objectSpread(_objectSpread({}, defaultButtonLabels), buttonLabels);

  var dirty = meta.dirty,
      submitFailed = meta.submitFailed,
      error = meta.error,
      submitError = meta.submitError;
  var isError = (dirty || submitFailed) && error && typeof error === 'string';
  return /*#__PURE__*/React.createElement(FieldArray, {
    key: rest.input.name,
    name: rest.input.name,
    validate: arrayValidator
  }, function (_ref4) {
    var _ref4$fields = _ref4.fields,
        map = _ref4$fields.map,
        _ref4$fields$value = _ref4$fields.value,
        value = _ref4$fields$value === void 0 ? [] : _ref4$fields$value,
        push = _ref4$fields.push,
        remove = _ref4$fields.remove;

    var pushWrapper = function pushWrapper() {
      dispatch({
        type: 'resetHistory'
      });
      push(defaultItem);
    };

    var removeWrapper = function removeWrapper(index) {
      dispatch({
        type: 'action',
        action: {
          action: 'remove',
          value: value[index]
        }
      });
      remove(index);
    };

    var undo = function undo() {
      push(state.history[state.index - 1].value);
      dispatch({
        type: 'undo'
      });
    };

    var redo = function redo() {
      remove(value.length - 1);
      dispatch({
        type: 'redo'
      });
    };

    return /*#__PURE__*/React.createElement("div", FieldArrayGridProps, /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.arrayHeader, arrayHeaderClassName)
    }, FieldArrayHeaderProps), label && /*#__PURE__*/React.createElement(FormField, {
      className: classes.noMargin,
      error: isError && {
        content: error,
        color: 'red',
        pointing: 'left'
      },
      control: function control() {
        return /*#__PURE__*/React.createElement(Header, {
          floated: "left",
          className: clsx(classes.noMargin, _defineProperty({}, classes.error, isError)),
          size: "large"
        }, label);
      }
    }), /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.buttonGroup, arrayButtonGridClassName)
    }, FieldArrayButtonGridProps), /*#__PURE__*/React.createElement(ButtonGroup, ButtonGroupProps, /*#__PURE__*/React.createElement(Button, _extends({
      icon: "undo",
      className: "ddorg__suir__mapper__field-array-undo"
    }, UndoButtonProps, {
      type: "button",
      disabled: state.index === 0,
      onClick: undo
    })), /*#__PURE__*/React.createElement(Button, _extends({
      icon: "redo",
      className: "ddorg__suir__mapper__field-array-redo"
    }, RedoButtonProps, {
      type: "button",
      disabled: state.index === state.history.length,
      onClick: redo
    })), /*#__PURE__*/React.createElement(Button, _extends({
      content: combinedButtonLabels.add,
      icon: "add",
      color: "blue"
    }, AddButtonProps, {
      type: "button",
      onClick: pushWrapper,
      disabled: value.length >= maxItems
    }))))), description && /*#__PURE__*/React.createElement(Header, _extends({
      className: clsx(classes.noMargin, descriptionClassName),
      sub: true
    }, DescriptionProps), description), /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.arrayItems, arrayItemsClassName)
    }, ArrayItemsGridProps), value.length <= 0 ? /*#__PURE__*/React.createElement("p", _extends({
      className: clsx(classes.noItems, noItemsClassname)
    }, NoItemsProps), noItemsMessage) : map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        removeLabel: combinedButtonLabels.remove,
        fieldIndex: index,
        fields: formFields,
        key: name,
        name: name,
        length: value.length,
        minItems: minItems,
        remove: removeWrapper,
        RemoveButtonProps: RemoveButtonProps,
        ArrayItemGridProps: ArrayItemGridProps,
        ArrayItemFieldsGridProps: ArrayItemFieldsGridProps
      });
    })), (isError || submitError) && /*#__PURE__*/React.createElement("div", {
      className: "ddorg__suir__mapper__field-array-error"
    }, /*#__PURE__*/React.createElement("p", null, error || submitError)));
  });
};

DynamicArray.propTypes = {
  label: PropTypes.node,
  description: PropTypes.node,
  fields: PropTypes.arrayOf(PropTypes.object).isRequired,
  defaultItem: PropTypes.any,
  minItems: PropTypes.number,
  maxItems: PropTypes.number,
  noItemsMessage: PropTypes.node,
  buttonLabels: PropTypes.object,

  /** Sub components customization API */
  FieldArrayGridProps: PropTypes.object,
  FieldArrayHeaderProps: PropTypes.object,
  FieldArrayButtonGridProps: PropTypes.object,
  ButtonGroupProps: PropTypes.object,
  UndoButtonProps: PropTypes.object,
  RedoButtonProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  DescriptionProps: PropTypes.object,
  ArrayItemsGridProps: PropTypes.object,
  NoItemsProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  ArrayItemGridProps: PropTypes.object,
  ArrayItemFieldsGridProps: PropTypes.object
};
DynamicArray.defaultProps = {
  maxItems: Infinity,
  minItems: 0,
  noItemsMessage: 'No items added',
  FieldArrayGridProps: {},
  FieldArrayHeaderProps: {},
  FieldArrayButtonGridProps: {},
  ButtonGroupProps: {},
  UndoButtonProps: {},
  RedoButtonProps: {},
  AddButtonProps: {},
  DescriptionProps: {},
  ArrayItemsGridProps: {},
  NoItemsProps: {},
  RemoveButtonProps: {},
  ArrayItemGridProps: {},
  ArrayItemFieldsGridProps: {}
};
export default DynamicArray;

==> suir-component-mapper-3.6.1.tgz: package/esm/field-array/field-array.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { memo, useReducer } from 'react';
import PropTypes from 'prop-types';
import isEqual from 'lodash/isEqual';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArray from "@data-driven-forms/react-form-renderer/field-array";
import Button from "semantic-ui-react/dist/es/elements/Button/Button.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import ButtonGroup from "semantic-ui-react/dist/es/elements/Button/ButtonGroup.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import { createUseStyles } from 'react-jss';
import clsx from 'clsx';
import FormField from '../form-field/form-field';
var useStyles = createUseStyles({
  buttonGroup: {
    display: 'flex',
    justifyContent: 'flex-end'
  },
  arrayItem: {
    marginBottom: '1em'
  },
  arrayItems: {
    marginTop: '1em'
  },
  error: {
    color: '#9f3a38 !important'
  },
  noItems: {
    paddingBottom: '1em'
  },
  noMargin: {
    margin: '0 !important'
  },
  arrayHeader: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center'
  }
});
var ArrayItem = memo(function (_ref) {
  var fields = _ref.fields,
      fieldIndex = _ref.fieldIndex,
      name = _ref.name,
      remove = _ref.remove,
      length = _ref.length,
      minItems = _ref.minItems,
      removeLabel = _ref.removeLabel,
      RemoveButtonProps = _ref.RemoveButtonProps,
      _ref$ArrayItemGridPro = _ref.ArrayItemGridProps,
      arrayItemClassName = _ref$ArrayItemGridPro.className,
      ArrayItemGridProps = _objectWithoutProperties(_ref$ArrayItemGridPro, ["className"]),
      ArrayItemFieldsGridProps = _ref.ArrayItemFieldsGridProps;

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  var classes = useStyles();
  var editedFields = fields.map(function (field, index) {
    var computedName = field.name ? "".concat(name, ".").concat(field.name) : name;
    return _objectSpread(_objectSpread({}, field), {}, {
      name: computedName,
      key: "".concat(computedName, "-").concat(index)
    });
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    className: clsx(classes.arrayItem, arrayItemClassName)
  }, ArrayItemGridProps), /*#__PURE__*/React.createElement("div", ArrayItemFieldsGridProps, renderForm([editedFields])), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Button, _extends({
    icon: "remove",
    content: removeLabel,
    basic: true,
    color: "red"
  }, RemoveButtonProps, {
    type: "button",
    onClick: function onClick() {
      return remove(fieldIndex);
    },
    disabled: length <= minItems
  }))));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, ["remove"]);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, ["remove"]);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  name: PropTypes.string,
  fieldIndex: PropTypes.number.isRequired,
  fields: PropTypes.arrayOf(PropTypes.object),
  remove: PropTypes.func.isRequired,
  length: PropTypes.number,
  minItems: PropTypes.number,
  removeLabel: PropTypes.node.isRequired,
  RemoveButtonProps: PropTypes.object,
  ArrayItemGridProps: PropTypes.object,
  ArrayItemFieldsGridProps: PropTypes.object
};
ArrayItem.defaultProps = {
  RemoveButtonProps: {},
  ArrayItemGridProps: {},
  ArrayItemFieldsGridProps: {}
};
var defaultButtonLabels = {
  add: 'ADD',
  remove: 'REMOVE'
};
var initialState = {
  index: 0,
  history: []
};
export var reducer = function reducer(state, _ref4) {
  var type = _ref4.type,
      action = _ref4.action;

  switch (type) {
    case 'redo':
      return _objectSpread(_objectSpread({}, state), {}, {
        index: state.index + 1
      });

    case 'action':
      return {
        index: state.index + 1,
        history: [].concat(_toConsumableArray(state.history.slice(0, state.index)), [action])
      };

    case 'undo':
      return _objectSpread(_objectSpread({}, state), {}, {
        index: state.index - 1
      });

    case 'resetHistory':
      return _objectSpread(_objectSpread({}, state), {}, {
        history: state.history.slice(0, state.index)
      });

    default:
      return state;
  }
};

var DynamicArray = function DynamicArray(_ref5) {
  var props = _extends({}, _ref5);

  var _useFieldApi = useFieldApi(props),
      arrayValidator = _useFieldApi.arrayValidator,
      label = _useFieldApi.label,
      description = _useFieldApi.description,
      formFields = _useFieldApi.fields,
      defaultItem = _useFieldApi.defaultItem,
      meta = _useFieldApi.meta,
      minItems = _useFieldApi.minItems,
      maxItems = _useFieldApi.maxItems,
      noItemsMessage = _useFieldApi.noItemsMessage,
      buttonLabels = _useFieldApi.buttonLabels,
      FieldArrayGridProps = _useFieldApi.FieldArrayGridProps,
      _useFieldApi$FieldArr = _useFieldApi.FieldArrayHeaderProps,
      arrayHeaderClassName = _useFieldApi$FieldArr.className,
      FieldArrayHeaderProps = _objectWithoutProperties(_useFieldApi$FieldArr, ["className"]),
      _useFieldApi$FieldArr2 = _useFieldApi.FieldArrayButtonGridProps,
      arrayButtonGridClassName = _useFieldApi$FieldArr2.className,
      FieldArrayButtonGridProps = _objectWithoutProperties(_useFieldApi$FieldArr2, ["className"]),
      ButtonGroupProps = _useFieldApi.ButtonGroupProps,
      UndoButtonProps = _useFieldApi.UndoButtonProps,
      RedoButtonProps = _useFieldApi.RedoButtonProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      _useFieldApi$Descript = _useFieldApi.DescriptionProps,
      descriptionClassName = _useFieldApi$Descript.className,
      DescriptionProps = _objectWithoutProperties(_useFieldApi$Descript, ["className"]),
      _useFieldApi$ArrayIte = _useFieldApi.ArrayItemsGridProps,
      arrayItemsClassName = _useFieldApi$ArrayIte.className,
      ArrayItemsGridProps = _objectWithoutProperties(_useFieldApi$ArrayIte, ["className"]),
      _useFieldApi$NoItemsP = _useFieldApi.NoItemsProps,
      noItemsClassname = _useFieldApi$NoItemsP.className,
      NoItemsProps = _objectWithoutProperties(_useFieldApi$NoItemsP, ["className"]),
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      ArrayItemGridProps = _useFieldApi.ArrayItemGridProps,
      ArrayItemFieldsGridProps = _useFieldApi.ArrayItemFieldsGridProps,
      rest = _objectWithoutProperties(_useFieldApi, ["arrayValidator", "label", "description", "fields", "defaultItem", "meta", "minItems", "maxItems", "noItemsMessage", "buttonLabels", "FieldArrayGridProps", "FieldArrayHeaderProps", "FieldArrayButtonGridProps", "ButtonGroupProps", "UndoButtonProps", "RedoButtonProps", "AddButtonProps", "DescriptionProps", "ArrayItemsGridProps", "NoItemsProps", "RemoveButtonProps", "ArrayItemGridProps", "ArrayItemFieldsGridProps"]);

  var _useReducer = useReducer(reducer, initialState),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  var classes = useStyles();

  var combinedButtonLabels = _objectSpread(_objectSpread({}, defaultButtonLabels), buttonLabels);

  var dirty = meta.dirty,
      submitFailed = meta.submitFailed,
      error = meta.error,
      submitError = meta.submitError;
  var isError = (dirty || submitFailed) && error && typeof error === 'string';
  return /*#__PURE__*/React.createElement(FieldArray, {
    key: rest.input.name,
    name: rest.input.name,
    validate: arrayValidator
  }, function (_ref6) {
    var _ref6$fields = _ref6.fields,
        map = _ref6$fields.map,
        _ref6$fields$value = _ref6$fields.value,
        value = _ref6$fields$value === void 0 ? [] : _ref6$fields$value,
        push = _ref6$fields.push,
        remove = _ref6$fields.remove;

    var pushWrapper = function pushWrapper() {
      dispatch({
        type: 'resetHistory'
      });
      push(defaultItem);
    };

    var removeWrapper = function removeWrapper(index) {
      dispatch({
        type: 'action',
        action: {
          action: 'remove',
          value: value[index]
        }
      });
      remove(index);
    };

    var undo = function undo() {
      push(state.history[state.index - 1].value);
      dispatch({
        type: 'undo'
      });
    };

    var redo = function redo() {
      remove(value.length - 1);
      dispatch({
        type: 'redo'
      });
    };

    return /*#__PURE__*/React.createElement("div", FieldArrayGridProps, /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.arrayHeader, arrayHeaderClassName)
    }, FieldArrayHeaderProps), label && /*#__PURE__*/React.createElement(FormField, {
      className: classes.noMargin,
      error: isError && {
        content: error,
        color: 'red',
        pointing: 'left'
      },
      control: function control() {
        return /*#__PURE__*/React.createElement(Header, {
          floated: "left",
          className: clsx(classes.noMargin, _defineProperty({}, classes.error, isError)),
          size: "large"
        }, label);
      }
    }), /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.buttonGroup, arrayButtonGridClassName)
    }, FieldArrayButtonGridProps), /*#__PURE__*/React.createElement(ButtonGroup, ButtonGroupProps, /*#__PURE__*/React.createElement(Button, _extends({
      icon: "undo",
      className: "ddorg__suir__mapper__field-array-undo"
    }, UndoButtonProps, {
      type: "button",
      disabled: state.index === 0,
      onClick: undo
    })), /*#__PURE__*/React.createElement(Button, _extends({
      icon: "redo",
      className: "ddorg__suir__mapper__field-array-redo"
    }, RedoButtonProps, {
      type: "button",
      disabled: state.index === state.history.length,
      onClick: redo
    })), /*#__PURE__*/React.createElement(Button, _extends({
      content: combinedButtonLabels.add,
      icon: "add",
      color: "blue"
    }, AddButtonProps, {
      type: "button",
      onClick: pushWrapper,
      disabled: value.length >= maxItems
    }))))), description && /*#__PURE__*/React.createElement(Header, _extends({
      className: clsx(classes.noMargin, descriptionClassName),
      sub: true
    }, DescriptionProps), description), /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.arrayItems, arrayItemsClassName)
    }, ArrayItemsGridProps), value.length <= 0 ? /*#__PURE__*/React.createElement("p", _extends({
      className: clsx(classes.noItems, noItemsClassname)
    }, NoItemsProps), noItemsMessage) : map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        removeLabel: combinedButtonLabels.remove,
        fieldIndex: index,
        fields: formFields,
        key: name,
        name: name,
        length: value.length,
        minItems: minItems,
        remove: removeWrapper,
        RemoveButtonProps: RemoveButtonProps,
        ArrayItemGridProps: ArrayItemGridProps,
        ArrayItemFieldsGridProps: ArrayItemFieldsGridProps
      });
    })), (isError || submitError) && /*#__PURE__*/React.createElement("div", {
      className: "ddorg__suir__mapper__field-array-error"
    }, /*#__PURE__*/React.createElement("p", null, error || submitError)));
  });
};

DynamicArray.propTypes = {
  label: PropTypes.node,
  description: PropTypes.node,
  fields: PropTypes.arrayOf(PropTypes.object).isRequired,
  defaultItem: PropTypes.any,
  minItems: PropTypes.number,
  maxItems: PropTypes.number,
  noItemsMessage: PropTypes.node,
  buttonLabels: PropTypes.object,

  /** Sub components customization API */
  FieldArrayGridProps: PropTypes.object,
  FieldArrayHeaderProps: PropTypes.object,
  FieldArrayButtonGridProps: PropTypes.object,
  ButtonGroupProps: PropTypes.object,
  UndoButtonProps: PropTypes.object,
  RedoButtonProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  DescriptionProps: PropTypes.object,
  ArrayItemsGridProps: PropTypes.object,
  NoItemsProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  ArrayItemGridProps: PropTypes.object,
  ArrayItemFieldsGridProps: PropTypes.object
};
DynamicArray.defaultProps = {
  maxItems: Infinity,
  minItems: 0,
  noItemsMessage: 'No items added',
  FieldArrayGridProps: {},
  FieldArrayHeaderProps: {},
  FieldArrayButtonGridProps: {},
  ButtonGroupProps: {},
  UndoButtonProps: {},
  RedoButtonProps: {},
  AddButtonProps: {},
  DescriptionProps: {},
  ArrayItemsGridProps: {},
  NoItemsProps: {},
  RemoveButtonProps: {},
  ArrayItemGridProps: {},
  ArrayItemFieldsGridProps: {}
};
export default DynamicArray;
